 Reahl is a web application framework that allows a Python programmer to work in 
 terms of useful abstractions - using a single programming language.

 This package contains the core of the Reahl framework. 

 With Reahl, programming is done purely in Python, using concepts familiar 
 from GUI programming---like reusable Widgets and Events. There's no need 
 for a programmer to know several different languages (HTML, JavaScript, 
 template languages, etc) or to keep up with the tricks of these trades.

 The abstractions presented by Reahl relieve the programmer from the burden 
 of dealing with the annoying problems of the web: security, accessibility, 
 progressive enhancement (or graceful degradation) and browser quirks.

 Install Reahl by installing with extras, eg: pip install "reahl[declarative,sqlite,dev,doc]"
 to install everything needed to run Reahl on sqlite, the dev tools and documentation.

 See http://www.reahl.org/docs/current/tutorial/gettingstarted-install.d.html for
 installation instructions.
